;== Include MemoryMap, Vector Table, and HeaderInfo ==
.INCLUDE "header.inc"

;== Include SNES Initialization routines ==
.INCLUDE "InitSNES.asm"
.INCLUDE "LoadGraphics.asm"


;============================================================================
; Main Code
;============================================================================

.BANK 0 SLOT 0
.ORG 0
.SECTION "MainCode"

Start:
    InitSNES
    
    rep #$10
    sep #$20
    
    LoadPalette CloudPalette, 0, 2          ; simple cloud palette, only 2 colors
    LoadPalette LandPalette, 16, 20         ; The ghosthouse scene palette
    LoadBlockToVRAM LandTiles, $0000, $E80  ; Ghosthouse tiles
    LoadBlockToVRAM CloudTiles, $1000, $170 ; Cloud tiles
    LoadBlockToVRAM Maps, $0800, $1000      ; Ghosthouse and Cloud tilemaps
                                            ; stored sequentially
    
    jsr SetupVideo                          ; you know the drill
    
    lda #$80
    sta $4200                               ; enable VBlank
    
Loop:
    WAI
    
    jmp Loop
    
VBlank:
    rep #$30
    pha
    phx
    phy
    
    rep #$10
    sep #$20
    
    lda $4210
    
    lda $00
    ina
    and #$03
    sta $00
    bne end         ; This slowly scrolls the clouds
    lda $01
    ina
    sta $01
    sta $2111

end:    
    rep #$30
    ply
    plx
    pla
    RTI
    
    
SetupVideo:
    rep #$10
    sep #$20
    
    lda #$09
    sta $2105       ; mode 1 with priority bit set (give BG3 more priority)
    
    lda #%00001000
    sta $2107       ; $0800 = BG1 Map
    lda #%00001100  ; $0C00 = BG3 Map
    sta $2109
    
    stz $210B       ; $0000 = BG1 graphics data
    lda #$01
    sta $210C       ; $1000 = BG2 graphics data
    
    lda #%00000001
    sta $212C       ; Set BG1 mainscreen
    
    lda #%00000100
    sta $212D       ; Set BG3 subscreen
    
    lda #$02
    sta $2130       ; Enable Subscreen Color ADD/SUB
    
    lda #%00100001
    sta $2131       ; Color addition on BG1 and Backdrop color
    
    lda #$0F
    sta $2100       ; Screen on!
    
    RTS
    
.ENDS

.SECTION "CharacterData"
LandPalette:
    .INCBIN "gfx/ghosthouse.clr"
    
CloudPalette:
    .INCBIN "gfx/clouds.clr"        ; holds the backdrop color (black) and dark blue
                                ; for the clouds
LandTiles:
    .INCBIN "gfx/ghosthouse.pic"    ; $E80 bytes
    
CloudTiles:
    .INCBIN "gfx/clouds.pic"        ; $170 bytes
  
Maps:
    .INCBIN "gfx/ghosthouse2.map"
    .INCBIN "gfx/clouds.map"
    
.ENDS
    